#
# spec file for package python-boltons
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-boltons
Version:        24.1.0
Release:        1.2
Summary:        The "Boltons" utility package for Python
License:        BSD-3-Clause
URL:            https://github.com/mahmoud/boltons
Source:         https://files.pythonhosted.org/packages/source/b/boltons/boltons-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Boltons is a package containing over 160 utility types and functions
that can be used as a package or independently. Documentation is on
http://boltons.readthedocs.org.

%prep
%autosetup -p1 -n boltons-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md CHANGELOG.md docs/*.rst
%{python_sitelib}/boltons
%{python_sitelib}/boltons-%{version}.dist-info

%changelog
* Tue Nov 19 2024 Markéta Machová <mmachova@suse.com>
- Update to 24.1.0
  * Added max_depth parameter to fileutils.iter_find_files
  * Added enter parameter to iterutils.research to support traversing
    custom data types
  * Add optional print tracing for iterutils.remap for easier debugging
  * Fixed typeutils.Sentinel copy behavior to return self
  * Tentative Python 3.13 support
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 24.0.0:
  * Per the RFC in issue [#365][i339], boltons is now **Python 3
    only**. 3.7+ for now.
  * Added Python 3.12 support ([#361][i361])
  * Fix [dictutils.OneToOne][dictutils.OneToOne]'s `update()`
    behavior with empty iterables
* Tue Dec 26 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 23.0.0:
  * Overdue update for Python 3.10 and 3.11 support
  * Add [iterutils.chunk_ranges][iterutils.chunk_ranges]
  * Improvements to `SpooledBytesIO`/`SpooledStringIO`
  * Bugfix for infinite daterange issue when start and stop is
    the same ([#302][i302])
  * Fix `Bits.as_list` behavior ([#315][i315])
- deleted patches
  - fix-ecoutil-imports.patch (upstreamed)
  - getstate-to-through-methods.patch (upstreamed)
* Mon Jan 23 2023 Markéta Machová <mmachova@suse.com>
- Add patch getstate-to-through-methods.patch
  * Adds support for Python 3.11
* Mon Dec 13 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 21.0.0:
  * Fix OMD.addlist when the added list is empty
  * Add funcutils.noop, satisfying PEP 559
  * Support lists for iterutils.bucketize
  * Python 3.9 test fixes for OMD (PEP 584, see #271)
  * Make typeutils.make_sentinel more pickleable
  * jsonutils.reverse_iter_lines now works on Py3 and Windows
- Drop boltons-pr271-py39-frozendict.patch:
  * Included upstream.
- Add patch fix-ecoutil-imports.patch:
  * Support Python 3.10.
* Fri Mar 19 2021 Ben Greiner <code@bnavigator.de>
- Add boltons-pr271-py39-frozendict.patch
  * gh#mahmoud/boltons#271
  * gh#mahmoud/boltons#283
* Sat Jan 30 2021 John Vandenberg <jayvdb@gmail.com>
- Include CHANGELOG.md & docs/*.rst
- Update to v20.2.1
  * Improve import time of iterutils
  * Add custom repr parameter to funcutils.format_invocation
- from v20.2.0
  * Added iterutils.lstrip, iterutils.rstrip, iterutils.strip
  * More robust and complete strutils.strip_ansi
  * Add iterutils.untyped_sorted
  * Fixes to IndexedSet rsub and index methods
  * Expose text mode flag in fileutils.AtomicSaver
  * Add strutils.int_list_complement and
    strutils.int_list_to_int_tuples to the int_list suite
  * Docs: intersphinx links finally point to Python 3 docs
- from v20.1.0
  * Add funcutils.update_wrapper, used to make a wrapper function
    reflect various aspects of the wrapped function's API
  * Fix FunctionBuilder handling of functions without __module__
  * Add partial support to FunctionBuilder
  * Fix NetstringSocket's handling of arguments in read_ns
  * Fix IndexedSet's index() method to account for removals
  * Add seekable, readable, and writable to SpooledIOBase
  * Add a special case to singularize
  * Fix various warnings for Py3.9
* Wed Jan 22 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 20.0.0
  * New module pathutils
  * add strutils.unwrap_text which does what you think to wrapped text
  * iterutils.chunked to work with the bytes type
  * funcutils.format_invocation for formatting simple function calls func(pos1, pos2, kw_k=kw_v)
  * A bunch of small fixes and enhancements.
  * many more in upstream CHANGELOG.md
* Sat Mar  9 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite, using GitHub as sdist
- Update to v19.1.0
  * Quick release to enhance funcutils.FunctionBuilder and funcutils.wraps
    to maintain function annotations on Python 3+
- from v19.0.0
  * New types and utilities
    + dictutils.ManyToMany, complement of dictutils.OneToOne
    + dictutils.FrozenDict, immutable mapping
    + setutils.complement(), "negative" sets, useful for exclusion and
    many other set operations
    + iterutils.soft_sorted(), more flexible sorting of sequences
    + iterutils.flatten_iter() and .flatten(), collapse nested iterables
    + mathutils.Bits type, representing a bitstring and translating
    between integer, bytestring, hex, and boolean sequence representations
  * funcutils improvements
    + FunctionBuilder funcutils.wraps now support coroutines/async
    + FunctionBuilder.add_arg() allows the addition of arguments to the
    signature, to match FunctionBuilder.remove_arg()
    + Similarly funcutils.wraps() now takes an "expected" argument, to
    complement "injected"
  * Other bugfixes and improvements
    + cacheutils.LRI is now threadsafe and correctly handles duplicate keys
    + dictutils.subdict() returns the same type of dictionary it was passed
    + urlutils, better IPv6 support and URL behave more natively like strings
    + Improve singularization in strutils
    + Fix some deprecation warnings in Python 3.7
    + Document the change in dict constructor behavior affecting
    dictutils.OMD under Python 3.7+
- from v18.0.1
  * A few bugfixes and a handy text utility.
  * Add MultiSub for multiple string substitutions in a single call
  * `tableutils.Table.to_text()` is more Markdown compatible
  * `atomic_save` works better with `overwrite=True`
  * Reduced memory footprint on `tbutils._DeferredLine` with `__slots__`
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jun  7 2018 jengelh@inai.de
- Use a description that actually says what the package is about.
* Thu May  3 2018 toddrme2178@gmail.com
- Add license file
- Package readme file
- Use %%license tag
* Thu May  3 2018 toddrme2178@gmail.com
- Update to 18.0.0
  * Add <thead> and <tbody> structure to tableutils.Table HTML output, which helps with styling and other functionality (e.g., jQuery datatables).
  * Add dictutils.subdict() to get a filtered version of a dictionary based on a subset of keys.
  * Add beta version of cacheutils.MinIDMap.
* Sat Apr 15 2017 toddrme2178@gmail.com
- Update to 17.1.0
  * No upstream changelog
- Implement single-spec version
* Mon Mar 21 2016 toddrme2178@gmail.com
- Update t0 16.1.1
  * No upstream changelog
* Wed May 20 2015 toddrme2178@gmail.com
- Initial version
